# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/inference/v1/inference.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/inference/v1/inference.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.cli.v1 import cli_pb2 as tars_dot_cli_dot_v1_dot_cli__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!tars/inference/v1/inference.proto\x12\x11tars.inference.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x15tars/cli/v1/cli.proto\x1a\x17tars/docs/v1/docs.proto\"\xe9\x01\n\rPromptRequest\x12/\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x0e\x9a\xb5\x18\n\n\x08\x63ustomerR\ncustomerId\x12,\n\nproject_id\x18\x02 \x01(\tB\r\x9a\xb5\x18\t\n\x07projectR\tprojectId\x12\x14\n\x05model\x18\x03 \x01(\tR\x05model\x12\x1b\n\x06prompt\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x06prompt\x12\x15\n\x06key_id\x18\x05 \x01(\tR\x05keyId\x12/\n\x0fidempotency_key\x18\x63 \x01(\tB\x06\x9a\xb5\x18\x02\x10\x01R\x0eidempotencyKey\"\xd4\x01\n\x0ePromptResponse\x12#\n\ncompletion\x18\x01 \x01(\tB\x03\xe0\x41\x03R\ncompletion\x12\x19\n\x05model\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x05model\x12&\n\x0c\x64\x61taplane_id\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x0b\x64\x61taplaneId\x12(\n\rprompt_tokens\x18\x04 \x01(\x05\x42\x03\xe0\x41\x03R\x0cpromptTokens\x12\x30\n\x11\x63ompletion_tokens\x18\x05 \x01(\x05\x42\x03\xe0\x41\x03R\x10\x63ompletionTokens\"w\n\x16GetDataplaneURLRequest\x12,\n\nproject_id\x18\x01 \x01(\tB\r\x9a\xb5\x18\t\n\x07projectR\tprojectId\x12/\n\x0b\x63ustomer_id\x18\x02 \x01(\tB\x0e\x9a\xb5\x18\n\n\x08\x63ustomerR\ncustomerId\"\xb0\x01\n\x0c\x44\x61taplaneURL\x12\x15\n\x03url\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x03url\x12$\n\x0b\x63ustomer_id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\ncustomerId\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03R\tprojectId\x12&\n\x0cworkspace_id\x18\x04 \x01(\tB\x03\xe0\x41\x03R\x0bworkspaceId\x12\x17\n\x04name\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x04name\"]\n\x17GetDataplaneURLResponse\x12\x42\n\tdataplane\x18\x01 \x01(\x0b\x32\x1f.tars.inference.v1.DataplaneURLB\x03\xe0\x41\x03R\tdataplane\"\x1a\n\x18ListDataplaneURLsRequest\"a\n\x19ListDataplaneURLsResponse\x12\x44\n\ndataplanes\x18\x01 \x03(\x0b\x32\x1f.tars.inference.v1.DataplaneURLB\x03\xe0\x41\x03R\ndataplanes2\xd2\x04\n\x17InferenceIngressService\x12\xc0\x01\n\x06Prompt\x12 .tars.inference.v1.PromptRequest\x1a!.tars.inference.v1.PromptResponse\"q\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x10\x1a\x06prompt:\x06prompt\xa2\xb5\x18\rSend a prompt\x82\xd3\xe4\x93\x02>\"9/v1/customers/{customer_id}/projects/{project_id}/prompts:\x01*\x12\xb3\x01\n\x0fGetDataplaneURL\x12).tars.inference.v1.GetDataplaneURLRequest\x1a*.tars.inference.v1.GetDataplaneURLResponse\"I\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x0f:\rdataplane-url\xa2\xb5\x18\x11Get dataplane URL\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/dataplane-url\x12\xbd\x01\n\x11ListDataplaneURLs\x12+.tars.inference.v1.ListDataplaneURLsRequest\x1a,.tars.inference.v1.ListDataplaneURLsResponse\"M\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x10:\x0e\x64\x61taplane-urls\xa2\xb5\x18\x13List dataplane URLs\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/dataplane-urlsB\xcc\x01\n\x15\x63om.tars.inference.v1B\x0eInferenceProtoP\x01Z=github.com/tetrateio/fraser/api/tars/inference/v1;inferencev1\xa2\x02\x03TIX\xaa\x02\x11Tars.Inference.V1\xca\x02\x11Tars\\Inference\\V1\xe2\x02\x1dTars\\Inference\\V1\\GPBMetadata\xea\x02\x13Tars::Inference::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.inference.v1.inference_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.tars.inference.v1B\016InferenceProtoP\001Z=github.com/tetrateio/fraser/api/tars/inference/v1;inferencev1\242\002\003TIX\252\002\021Tars.Inference.V1\312\002\021Tars\\Inference\\V1\342\002\035Tars\\Inference\\V1\\GPBMetadata\352\002\023Tars::Inference::V1'
  _globals['_PROMPTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_PROMPTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\232\265\030\n\n\010customer'
  _globals['_PROMPTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_PROMPTREQUEST'].fields_by_name['project_id']._serialized_options = b'\232\265\030\t\n\007project'
  _globals['_PROMPTREQUEST'].fields_by_name['prompt']._loaded_options = None
  _globals['_PROMPTREQUEST'].fields_by_name['prompt']._serialized_options = b'\340A\002'
  _globals['_PROMPTREQUEST'].fields_by_name['idempotency_key']._loaded_options = None
  _globals['_PROMPTREQUEST'].fields_by_name['idempotency_key']._serialized_options = b'\232\265\030\002\020\001'
  _globals['_PROMPTRESPONSE'].fields_by_name['completion']._loaded_options = None
  _globals['_PROMPTRESPONSE'].fields_by_name['completion']._serialized_options = b'\340A\003'
  _globals['_PROMPTRESPONSE'].fields_by_name['model']._loaded_options = None
  _globals['_PROMPTRESPONSE'].fields_by_name['model']._serialized_options = b'\340A\003'
  _globals['_PROMPTRESPONSE'].fields_by_name['dataplane_id']._loaded_options = None
  _globals['_PROMPTRESPONSE'].fields_by_name['dataplane_id']._serialized_options = b'\340A\003'
  _globals['_PROMPTRESPONSE'].fields_by_name['prompt_tokens']._loaded_options = None
  _globals['_PROMPTRESPONSE'].fields_by_name['prompt_tokens']._serialized_options = b'\340A\003'
  _globals['_PROMPTRESPONSE'].fields_by_name['completion_tokens']._loaded_options = None
  _globals['_PROMPTRESPONSE'].fields_by_name['completion_tokens']._serialized_options = b'\340A\003'
  _globals['_GETDATAPLANEURLREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_GETDATAPLANEURLREQUEST'].fields_by_name['project_id']._serialized_options = b'\232\265\030\t\n\007project'
  _globals['_GETDATAPLANEURLREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_GETDATAPLANEURLREQUEST'].fields_by_name['customer_id']._serialized_options = b'\232\265\030\n\n\010customer'
  _globals['_DATAPLANEURL'].fields_by_name['url']._loaded_options = None
  _globals['_DATAPLANEURL'].fields_by_name['url']._serialized_options = b'\340A\003'
  _globals['_DATAPLANEURL'].fields_by_name['customer_id']._loaded_options = None
  _globals['_DATAPLANEURL'].fields_by_name['customer_id']._serialized_options = b'\340A\003'
  _globals['_DATAPLANEURL'].fields_by_name['project_id']._loaded_options = None
  _globals['_DATAPLANEURL'].fields_by_name['project_id']._serialized_options = b'\340A\003'
  _globals['_DATAPLANEURL'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_DATAPLANEURL'].fields_by_name['workspace_id']._serialized_options = b'\340A\003'
  _globals['_DATAPLANEURL'].fields_by_name['name']._loaded_options = None
  _globals['_DATAPLANEURL'].fields_by_name['name']._serialized_options = b'\340A\003'
  _globals['_GETDATAPLANEURLRESPONSE'].fields_by_name['dataplane']._loaded_options = None
  _globals['_GETDATAPLANEURLRESPONSE'].fields_by_name['dataplane']._serialized_options = b'\340A\003'
  _globals['_LISTDATAPLANEURLSRESPONSE'].fields_by_name['dataplanes']._loaded_options = None
  _globals['_LISTDATAPLANEURLSRESPONSE'].fields_by_name['dataplanes']._serialized_options = b'\340A\003'
  _globals['_INFERENCEINGRESSSERVICE'].methods_by_name['Prompt']._loaded_options = None
  _globals['_INFERENCEINGRESSSERVICE'].methods_by_name['Prompt']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\020\032\006prompt:\006prompt\242\265\030\rSend a prompt\202\323\344\223\002>\"9/v1/customers/{customer_id}/projects/{project_id}/prompts:\001*'
  _globals['_INFERENCEINGRESSSERVICE'].methods_by_name['GetDataplaneURL']._loaded_options = None
  _globals['_INFERENCEINGRESSSERVICE'].methods_by_name['GetDataplaneURL']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\017:\rdataplane-url\242\265\030\021Get dataplane URL\202\323\344\223\002\023\022\021/v1/dataplane-url'
  _globals['_INFERENCEINGRESSSERVICE'].methods_by_name['ListDataplaneURLs']._loaded_options = None
  _globals['_INFERENCEINGRESSSERVICE'].methods_by_name['ListDataplaneURLs']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\020:\016dataplane-urls\242\265\030\023List dataplane URLs\202\323\344\223\002\024\022\022/v1/dataplane-urls'
  _globals['_PROMPTREQUEST']._serialized_start=201
  _globals['_PROMPTREQUEST']._serialized_end=434
  _globals['_PROMPTRESPONSE']._serialized_start=437
  _globals['_PROMPTRESPONSE']._serialized_end=649
  _globals['_GETDATAPLANEURLREQUEST']._serialized_start=651
  _globals['_GETDATAPLANEURLREQUEST']._serialized_end=770
  _globals['_DATAPLANEURL']._serialized_start=773
  _globals['_DATAPLANEURL']._serialized_end=949
  _globals['_GETDATAPLANEURLRESPONSE']._serialized_start=951
  _globals['_GETDATAPLANEURLRESPONSE']._serialized_end=1044
  _globals['_LISTDATAPLANEURLSREQUEST']._serialized_start=1046
  _globals['_LISTDATAPLANEURLSREQUEST']._serialized_end=1072
  _globals['_LISTDATAPLANEURLSRESPONSE']._serialized_start=1074
  _globals['_LISTDATAPLANEURLSRESPONSE']._serialized_end=1171
  _globals['_INFERENCEINGRESSSERVICE']._serialized_start=1174
  _globals['_INFERENCEINGRESSSERVICE']._serialized_end=1768
# @@protoc_insertion_point(module_scope)



import datetime

from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from tars.auth.v1 import auth_options_pb2 as _auth_options_pb2
from tars.docs.v1 import docs_pb2 as _docs_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ConfigType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CONFIG_TYPE_UNSPECIFIED: _ClassVar[ConfigType]
    CONFIG_TYPE_GLOBAL_ROUTES: _ClassVar[ConfigType]
    CONFIG_TYPE_USER_ROUTES: _ClassVar[ConfigType]
    CONFIG_TYPE_BYOK: _ClassVar[ConfigType]
    CONFIG_TYPE_MCP_PROFILE: _ClassVar[ConfigType]
    CONFIG_TYPE_MCP_BACKENDS: _ClassVar[ConfigType]
    CONFIG_TYPE_OAUTH_TOKEN: _ClassVar[ConfigType]
    CONFIG_TYPE_BYOK_BACKENDS: _ClassVar[ConfigType]
    CONFIG_TYPE_GUARDRAILS: _ClassVar[ConfigType]
    CONFIG_TYPE_PROXY_URL: _ClassVar[ConfigType]
    CONFIG_TYPE_PROXY: _ClassVar[ConfigType]
    CONFIG_TYPE_PROVIDER_SECRETS: _ClassVar[ConfigType]
    CONFIG_TYPE_DATAPLANE_UPGRADE: _ClassVar[ConfigType]
    CONFIG_TYPE_BYOK_SCOPED: _ClassVar[ConfigType]

class EventType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    EVENT_TYPE_UNSPECIFIED: _ClassVar[EventType]
    EVENT_TYPE_NEW: _ClassVar[EventType]
    EVENT_TYPE_UPDATE: _ClassVar[EventType]
    EVENT_TYPE_UPGRADE: _ClassVar[EventType]
    EVENT_TYPE_UPGRADE_CANCEL: _ClassVar[EventType]
    EVENT_TYPE_UPGRADE_ROLLBACK: _ClassVar[EventType]
    EVENT_TYPE_DELETE: _ClassVar[EventType]
    EVENT_TYPE_UPDATE_BYOK: _ClassVar[EventType]
    EVENT_TYPE_UPDATE_MCP: _ClassVar[EventType]
    EVENT_TYPE_UPDATE_OAUTH: _ClassVar[EventType]
CONFIG_TYPE_UNSPECIFIED: ConfigType
CONFIG_TYPE_GLOBAL_ROUTES: ConfigType
CONFIG_TYPE_USER_ROUTES: ConfigType
CONFIG_TYPE_BYOK: ConfigType
CONFIG_TYPE_MCP_PROFILE: ConfigType
CONFIG_TYPE_MCP_BACKENDS: ConfigType
CONFIG_TYPE_OAUTH_TOKEN: ConfigType
CONFIG_TYPE_BYOK_BACKENDS: ConfigType
CONFIG_TYPE_GUARDRAILS: ConfigType
CONFIG_TYPE_PROXY_URL: ConfigType
CONFIG_TYPE_PROXY: ConfigType
CONFIG_TYPE_PROVIDER_SECRETS: ConfigType
CONFIG_TYPE_DATAPLANE_UPGRADE: ConfigType
CONFIG_TYPE_BYOK_SCOPED: ConfigType
EVENT_TYPE_UNSPECIFIED: EventType
EVENT_TYPE_NEW: EventType
EVENT_TYPE_UPDATE: EventType
EVENT_TYPE_UPGRADE: EventType
EVENT_TYPE_UPGRADE_CANCEL: EventType
EVENT_TYPE_UPGRADE_ROLLBACK: EventType
EVENT_TYPE_DELETE: EventType
EVENT_TYPE_UPDATE_BYOK: EventType
EVENT_TYPE_UPDATE_MCP: EventType
EVENT_TYPE_UPDATE_OAUTH: EventType

class GetConfigurationRequest(_message.Message):
    __slots__ = ("queries",)
    QUERIES_FIELD_NUMBER: _ClassVar[int]
    queries: _containers.RepeatedCompositeFieldContainer[UserConfigQuery]
    def __init__(self, queries: _Optional[_Iterable[_Union[UserConfigQuery, _Mapping]]] = ...) -> None: ...

class UserConfigQuery(_message.Message):
    __slots__ = ("user_id", "config_type", "current_version", "key_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    CONFIG_TYPE_FIELD_NUMBER: _ClassVar[int]
    CURRENT_VERSION_FIELD_NUMBER: _ClassVar[int]
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    config_type: ConfigType
    current_version: int
    key_id: str
    def __init__(self, user_id: _Optional[str] = ..., config_type: _Optional[_Union[ConfigType, str]] = ..., current_version: _Optional[int] = ..., key_id: _Optional[str] = ...) -> None: ...

class GetConfigurationResponse(_message.Message):
    __slots__ = ("configurations",)
    CONFIGURATIONS_FIELD_NUMBER: _ClassVar[int]
    configurations: _containers.RepeatedCompositeFieldContainer[Configuration]
    def __init__(self, configurations: _Optional[_Iterable[_Union[Configuration, _Mapping]]] = ...) -> None: ...

class TriggerUpdateRequest(_message.Message):
    __slots__ = ("user_id", "config_type", "event_type", "key_id", "workspace_id", "metadata")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    CONFIG_TYPE_FIELD_NUMBER: _ClassVar[int]
    EVENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    config_type: ConfigType
    event_type: EventType
    key_id: str
    workspace_id: str
    metadata: TriggerMetadata
    def __init__(self, user_id: _Optional[str] = ..., config_type: _Optional[_Union[ConfigType, str]] = ..., event_type: _Optional[_Union[EventType, str]] = ..., key_id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., metadata: _Optional[_Union[TriggerMetadata, _Mapping]] = ...) -> None: ...

class TriggerMetadata(_message.Message):
    __slots__ = ("dataplane_upgrade",)
    DATAPLANE_UPGRADE_FIELD_NUMBER: _ClassVar[int]
    dataplane_upgrade: DataplaneUpgradeTrigger
    def __init__(self, dataplane_upgrade: _Optional[_Union[DataplaneUpgradeTrigger, _Mapping]] = ...) -> None: ...

class DataplaneUpgradeTrigger(_message.Message):
    __slots__ = ("target_version", "allow_downtime", "credentials_ref", "persist_in_cluster", "acknowledged_preflight_checks")
    TARGET_VERSION_FIELD_NUMBER: _ClassVar[int]
    ALLOW_DOWNTIME_FIELD_NUMBER: _ClassVar[int]
    CREDENTIALS_REF_FIELD_NUMBER: _ClassVar[int]
    PERSIST_IN_CLUSTER_FIELD_NUMBER: _ClassVar[int]
    ACKNOWLEDGED_PREFLIGHT_CHECKS_FIELD_NUMBER: _ClassVar[int]
    target_version: str
    allow_downtime: bool
    credentials_ref: str
    persist_in_cluster: bool
    acknowledged_preflight_checks: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, target_version: _Optional[str] = ..., allow_downtime: _Optional[bool] = ..., credentials_ref: _Optional[str] = ..., persist_in_cluster: _Optional[bool] = ..., acknowledged_preflight_checks: _Optional[_Iterable[str]] = ...) -> None: ...

class TriggerUpdateResponse(_message.Message):
    __slots__ = ("configuration", "configuration_updated")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATION_UPDATED_FIELD_NUMBER: _ClassVar[int]
    configuration: Configuration
    configuration_updated: bool
    def __init__(self, configuration: _Optional[_Union[Configuration, _Mapping]] = ..., configuration_updated: _Optional[bool] = ...) -> None: ...

class ListConfigurationsRequest(_message.Message):
    __slots__ = ("user_id", "config_type", "page_size", "page_token")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    CONFIG_TYPE_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    config_type: ConfigType
    page_size: int
    page_token: str
    def __init__(self, user_id: _Optional[str] = ..., config_type: _Optional[_Union[ConfigType, str]] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class ListConfigurationsResponse(_message.Message):
    __slots__ = ("configurations", "next_page_token")
    CONFIGURATIONS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    configurations: _containers.RepeatedCompositeFieldContainer[Configuration]
    next_page_token: str
    def __init__(self, configurations: _Optional[_Iterable[_Union[Configuration, _Mapping]]] = ..., next_page_token: _Optional[str] = ...) -> None: ...

class ListPendingEventsRequest(_message.Message):
    __slots__ = ("limit", "doctor_runtime")
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    DOCTOR_RUNTIME_FIELD_NUMBER: _ClassVar[int]
    limit: int
    doctor_runtime: DoctorRuntimeStatus
    def __init__(self, limit: _Optional[int] = ..., doctor_runtime: _Optional[_Union[DoctorRuntimeStatus, _Mapping]] = ...) -> None: ...

class DoctorRuntimeStatus(_message.Message):
    __slots__ = ("instance_id", "tare_version", "state", "reason", "last_successful_run", "observed_at")
    INSTANCE_ID_FIELD_NUMBER: _ClassVar[int]
    TARE_VERSION_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    LAST_SUCCESSFUL_RUN_FIELD_NUMBER: _ClassVar[int]
    OBSERVED_AT_FIELD_NUMBER: _ClassVar[int]
    instance_id: str
    tare_version: str
    state: str
    reason: str
    last_successful_run: _timestamp_pb2.Timestamp
    observed_at: _timestamp_pb2.Timestamp
    def __init__(self, instance_id: _Optional[str] = ..., tare_version: _Optional[str] = ..., state: _Optional[str] = ..., reason: _Optional[str] = ..., last_successful_run: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., observed_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ListPendingEventsResponse(_message.Message):
    __slots__ = ("events",)
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    events: _containers.RepeatedCompositeFieldContainer[ConfigurationEvent]
    def __init__(self, events: _Optional[_Iterable[_Union[ConfigurationEvent, _Mapping]]] = ...) -> None: ...

class ReconcileWorkspaceRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ReconcileWorkspaceResponse(_message.Message):
    __slots__ = ("replayed_total", "replayed_global", "replayed_per_user", "replayed_per_user_per_key")
    REPLAYED_TOTAL_FIELD_NUMBER: _ClassVar[int]
    REPLAYED_GLOBAL_FIELD_NUMBER: _ClassVar[int]
    REPLAYED_PER_USER_FIELD_NUMBER: _ClassVar[int]
    REPLAYED_PER_USER_PER_KEY_FIELD_NUMBER: _ClassVar[int]
    replayed_total: int
    replayed_global: int
    replayed_per_user: int
    replayed_per_user_per_key: int
    def __init__(self, replayed_total: _Optional[int] = ..., replayed_global: _Optional[int] = ..., replayed_per_user: _Optional[int] = ..., replayed_per_user_per_key: _Optional[int] = ...) -> None: ...

class FullSyncWorkspaceRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class FullSyncWorkspaceResponse(_message.Message):
    __slots__ = ("replayed_total", "replayed_per_user", "replayed_per_user_per_key")
    REPLAYED_TOTAL_FIELD_NUMBER: _ClassVar[int]
    REPLAYED_PER_USER_FIELD_NUMBER: _ClassVar[int]
    REPLAYED_PER_USER_PER_KEY_FIELD_NUMBER: _ClassVar[int]
    replayed_total: int
    replayed_per_user: int
    replayed_per_user_per_key: int
    def __init__(self, replayed_total: _Optional[int] = ..., replayed_per_user: _Optional[int] = ..., replayed_per_user_per_key: _Optional[int] = ...) -> None: ...

class ConfigurationEvent(_message.Message):
    __slots__ = ("id", "user_id", "config_type", "event_type", "key_id", "config_id", "config_version", "status", "triggered_at", "retry_count", "workspace_id", "metadata")
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    CONFIG_TYPE_FIELD_NUMBER: _ClassVar[int]
    EVENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    CONFIG_VERSION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TRIGGERED_AT_FIELD_NUMBER: _ClassVar[int]
    RETRY_COUNT_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    id: str
    user_id: str
    config_type: ConfigType
    event_type: str
    key_id: str
    config_id: str
    config_version: int
    status: str
    triggered_at: _timestamp_pb2.Timestamp
    retry_count: int
    workspace_id: str
    metadata: str
    def __init__(self, id: _Optional[str] = ..., user_id: _Optional[str] = ..., config_type: _Optional[_Union[ConfigType, str]] = ..., event_type: _Optional[str] = ..., key_id: _Optional[str] = ..., config_id: _Optional[str] = ..., config_version: _Optional[int] = ..., status: _Optional[str] = ..., triggered_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., retry_count: _Optional[int] = ..., workspace_id: _Optional[str] = ..., metadata: _Optional[str] = ...) -> None: ...

class AcknowledgeEventRequest(_message.Message):
    __slots__ = ("event_id", "worker_id")
    EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    WORKER_ID_FIELD_NUMBER: _ClassVar[int]
    event_id: str
    worker_id: str
    def __init__(self, event_id: _Optional[str] = ..., worker_id: _Optional[str] = ...) -> None: ...

class AcknowledgeEventResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: _Optional[bool] = ...) -> None: ...

class CompleteEventRequest(_message.Message):
    __slots__ = ("event_id", "success", "error_message")
    EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    event_id: str
    success: bool
    error_message: str
    def __init__(self, event_id: _Optional[str] = ..., success: _Optional[bool] = ..., error_message: _Optional[str] = ...) -> None: ...

class CompleteEventResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: _Optional[bool] = ...) -> None: ...

class ListActiveUsersRequest(_message.Message):
    __slots__ = ("limit",)
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    limit: int
    def __init__(self, limit: _Optional[int] = ...) -> None: ...

class ListActiveUsersResponse(_message.Message):
    __slots__ = ("user_ids",)
    USER_IDS_FIELD_NUMBER: _ClassVar[int]
    user_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, user_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class Configuration(_message.Message):
    __slots__ = ("id", "user_id", "config_type", "config_data", "version", "key_id", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    CONFIG_TYPE_FIELD_NUMBER: _ClassVar[int]
    CONFIG_DATA_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    user_id: str
    config_type: ConfigType
    config_data: str
    version: int
    key_id: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., user_id: _Optional[str] = ..., config_type: _Optional[_Union[ConfigType, str]] = ..., config_data: _Optional[str] = ..., version: _Optional[int] = ..., key_id: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ProviderBackend(_message.Message):
    __slots__ = ("name", "owner", "provider", "weight", "priority", "byok_policy", "is_external", "model_name")
    NAME_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_FIELD_NUMBER: _ClassVar[int]
    BYOK_POLICY_FIELD_NUMBER: _ClassVar[int]
    IS_EXTERNAL_FIELD_NUMBER: _ClassVar[int]
    MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    owner: str
    provider: str
    weight: int
    priority: int
    byok_policy: str
    is_external: bool
    model_name: str
    def __init__(self, name: _Optional[str] = ..., owner: _Optional[str] = ..., provider: _Optional[str] = ..., weight: _Optional[int] = ..., priority: _Optional[int] = ..., byok_policy: _Optional[str] = ..., is_external: _Optional[bool] = ..., model_name: _Optional[str] = ...) -> None: ...

class SaveBYOKBackendsRequest(_message.Message):
    __slots__ = ("user_id", "key_address", "backends")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    KEY_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    BACKENDS_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    key_address: str
    backends: _containers.RepeatedCompositeFieldContainer[ProviderBackend]
    def __init__(self, user_id: _Optional[str] = ..., key_address: _Optional[str] = ..., backends: _Optional[_Iterable[_Union[ProviderBackend, _Mapping]]] = ...) -> None: ...

class SaveBYOKBackendsResponse(_message.Message):
    __slots__ = ("configuration", "updated")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    UPDATED_FIELD_NUMBER: _ClassVar[int]
    configuration: Configuration
    updated: bool
    def __init__(self, configuration: _Optional[_Union[Configuration, _Mapping]] = ..., updated: _Optional[bool] = ...) -> None: ...

class DeleteBYOKBackendsRequest(_message.Message):
    __slots__ = ("user_id",)
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    def __init__(self, user_id: _Optional[str] = ...) -> None: ...

class DeleteBYOKBackendsResponse(_message.Message):
    __slots__ = ("deleted",)
    DELETED_FIELD_NUMBER: _ClassVar[int]
    deleted: bool
    def __init__(self, deleted: _Optional[bool] = ...) -> None: ...

class RevokeUserTokenRequest(_message.Message):
    __slots__ = ("jti", "user_id", "reason")
    JTI_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    jti: str
    user_id: str
    reason: str
    def __init__(self, jti: _Optional[str] = ..., user_id: _Optional[str] = ..., reason: _Optional[str] = ...) -> None: ...

class RevokeUserTokenResponse(_message.Message):
    __slots__ = ("success", "revoked_at")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    REVOKED_AT_FIELD_NUMBER: _ClassVar[int]
    success: bool
    revoked_at: _timestamp_pb2.Timestamp
    def __init__(self, success: _Optional[bool] = ..., revoked_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class Provider(_message.Message):
    __slots__ = ("slug", "display_name", "api_base_url", "auth_type", "is_enabled", "metadata", "created_at", "updated_at")
    SLUG_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    API_BASE_URL_FIELD_NUMBER: _ClassVar[int]
    AUTH_TYPE_FIELD_NUMBER: _ClassVar[int]
    IS_ENABLED_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    slug: str
    display_name: str
    api_base_url: str
    auth_type: str
    is_enabled: bool
    metadata: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, slug: _Optional[str] = ..., display_name: _Optional[str] = ..., api_base_url: _Optional[str] = ..., auth_type: _Optional[str] = ..., is_enabled: _Optional[bool] = ..., metadata: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ListActiveProvidersRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListActiveProvidersResponse(_message.Message):
    __slots__ = ("providers",)
    PROVIDERS_FIELD_NUMBER: _ClassVar[int]
    providers: _containers.RepeatedCompositeFieldContainer[Provider]
    def __init__(self, providers: _Optional[_Iterable[_Union[Provider, _Mapping]]] = ...) -> None: ...

class SetDataplaneURLRequest(_message.Message):
    __slots__ = ("workspace_id", "url", "trigger_update")
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    TRIGGER_UPDATE_FIELD_NUMBER: _ClassVar[int]
    workspace_id: str
    url: str
    trigger_update: bool
    def __init__(self, workspace_id: _Optional[str] = ..., url: _Optional[str] = ..., trigger_update: _Optional[bool] = ...) -> None: ...

class SetDataplaneURLResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpsertMCPCatalogServerRequest(_message.Message):
    __slots__ = ("workspace_id", "id", "url", "name", "description", "icon_url", "categories", "authentication", "requires_auth", "force_overwrite")
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ICON_URL_FIELD_NUMBER: _ClassVar[int]
    CATEGORIES_FIELD_NUMBER: _ClassVar[int]
    AUTHENTICATION_FIELD_NUMBER: _ClassVar[int]
    REQUIRES_AUTH_FIELD_NUMBER: _ClassVar[int]
    FORCE_OVERWRITE_FIELD_NUMBER: _ClassVar[int]
    workspace_id: str
    id: str
    url: str
    name: str
    description: str
    icon_url: str
    categories: _containers.RepeatedScalarFieldContainer[str]
    authentication: str
    requires_auth: bool
    force_overwrite: bool
    def __init__(self, workspace_id: _Optional[str] = ..., id: _Optional[str] = ..., url: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., icon_url: _Optional[str] = ..., categories: _Optional[_Iterable[str]] = ..., authentication: _Optional[str] = ..., requires_auth: _Optional[bool] = ..., force_overwrite: _Optional[bool] = ...) -> None: ...

class UpsertMCPCatalogServerResponse(_message.Message):
    __slots__ = ("created",)
    CREATED_FIELD_NUMBER: _ClassVar[int]
    created: bool
    def __init__(self, created: _Optional[bool] = ...) -> None: ...

class ValidateDataplaneRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ValidateDataplaneResponse(_message.Message):
    __slots__ = ("gatekeeper_public_keys",)
    GATEKEEPER_PUBLIC_KEYS_FIELD_NUMBER: _ClassVar[int]
    gatekeeper_public_keys: _containers.RepeatedCompositeFieldContainer[GatekeeperPublicKey]
    def __init__(self, gatekeeper_public_keys: _Optional[_Iterable[_Union[GatekeeperPublicKey, _Mapping]]] = ...) -> None: ...

class GatekeeperPublicKey(_message.Message):
    __slots__ = ("kid", "alg", "use", "public_key_pem")
    KID_FIELD_NUMBER: _ClassVar[int]
    ALG_FIELD_NUMBER: _ClassVar[int]
    USE_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_PEM_FIELD_NUMBER: _ClassVar[int]
    kid: str
    alg: str
    use: str
    public_key_pem: str
    def __init__(self, kid: _Optional[str] = ..., alg: _Optional[str] = ..., use: _Optional[str] = ..., public_key_pem: _Optional[str] = ...) -> None: ...

class UpdateEventMetadataRequest(_message.Message):
    __slots__ = ("event_id", "metadata")
    EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    event_id: str
    metadata: str
    def __init__(self, event_id: _Optional[str] = ..., metadata: _Optional[str] = ...) -> None: ...

class UpdateEventMetadataResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: _Optional[bool] = ...) -> None: ...

class CancelDataplaneUpgradeRequest(_message.Message):
    __slots__ = ("upgrade_event_id",)
    UPGRADE_EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    upgrade_event_id: str
    def __init__(self, upgrade_event_id: _Optional[str] = ...) -> None: ...

class CancelDataplaneUpgradeResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: _Optional[bool] = ...) -> None: ...

class RollbackDataplaneUpgradeRequest(_message.Message):
    __slots__ = ("upgrade_event_id",)
    UPGRADE_EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    upgrade_event_id: str
    def __init__(self, upgrade_event_id: _Optional[str] = ...) -> None: ...

class RollbackDataplaneUpgradeResponse(_message.Message):
    __slots__ = ("success", "rollback_event_id")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ROLLBACK_EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    success: bool
    rollback_event_id: str
    def __init__(self, success: _Optional[bool] = ..., rollback_event_id: _Optional[str] = ...) -> None: ...

class DataplaneUpgradeCredential(_message.Message):
    __slots__ = ("slot", "username", "password", "registry")
    SLOT_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    REGISTRY_FIELD_NUMBER: _ClassVar[int]
    slot: str
    username: str
    password: str
    registry: str
    def __init__(self, slot: _Optional[str] = ..., username: _Optional[str] = ..., password: _Optional[str] = ..., registry: _Optional[str] = ...) -> None: ...

class SubmitDataplaneUpgradeCredentialsRequest(_message.Message):
    __slots__ = ("upgrade_event_id", "credentials", "persist_in_cluster")
    UPGRADE_EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    CREDENTIALS_FIELD_NUMBER: _ClassVar[int]
    PERSIST_IN_CLUSTER_FIELD_NUMBER: _ClassVar[int]
    upgrade_event_id: str
    credentials: _containers.RepeatedCompositeFieldContainer[DataplaneUpgradeCredential]
    persist_in_cluster: bool
    def __init__(self, upgrade_event_id: _Optional[str] = ..., credentials: _Optional[_Iterable[_Union[DataplaneUpgradeCredential, _Mapping]]] = ..., persist_in_cluster: _Optional[bool] = ...) -> None: ...

class SubmitDataplaneUpgradeCredentialsResponse(_message.Message):
    __slots__ = ("credentials_id", "success")
    CREDENTIALS_ID_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    credentials_id: str
    success: bool
    def __init__(self, credentials_id: _Optional[str] = ..., success: _Optional[bool] = ...) -> None: ...

class GetDataplaneUpgradeCredentialsRequest(_message.Message):
    __slots__ = ("upgrade_event_id",)
    UPGRADE_EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    upgrade_event_id: str
    def __init__(self, upgrade_event_id: _Optional[str] = ...) -> None: ...

class GetDataplaneUpgradeCredentialsResponse(_message.Message):
    __slots__ = ("credentials", "present", "persist_in_cluster")
    CREDENTIALS_FIELD_NUMBER: _ClassVar[int]
    PRESENT_FIELD_NUMBER: _ClassVar[int]
    PERSIST_IN_CLUSTER_FIELD_NUMBER: _ClassVar[int]
    credentials: _containers.RepeatedCompositeFieldContainer[DataplaneUpgradeCredential]
    present: bool
    persist_in_cluster: bool
    def __init__(self, credentials: _Optional[_Iterable[_Union[DataplaneUpgradeCredential, _Mapping]]] = ..., present: _Optional[bool] = ..., persist_in_cluster: _Optional[bool] = ...) -> None: ...

class AckDataplaneUpgradeCredentialsRequest(_message.Message):
    __slots__ = ("upgrade_event_id", "delivered")
    UPGRADE_EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    DELIVERED_FIELD_NUMBER: _ClassVar[int]
    upgrade_event_id: str
    delivered: bool
    def __init__(self, upgrade_event_id: _Optional[str] = ..., delivered: _Optional[bool] = ...) -> None: ...

class AckDataplaneUpgradeCredentialsResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: _Optional[bool] = ...) -> None: ...



import datetime

from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from tars.auth.v1 import auth_options_pb2 as _auth_options_pb2
from tars.cli.v1 import cli_pb2 as _cli_pb2
from tars.common.v1 import types_pb2 as _types_pb2
from tars.docs.v1 import docs_pb2 as _docs_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class McpOAuthClient(_message.Message):
    __slots__ = ("id", "customer_id", "project_id", "provider", "provider_name", "client_id", "authorization_url", "token_url", "scopes", "redirect_uris", "metadata", "server_ids", "status", "created_at", "updated_at")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_NAME_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    AUTHORIZATION_URL_FIELD_NUMBER: _ClassVar[int]
    TOKEN_URL_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URIS_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SERVER_IDS_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    customer_id: str
    project_id: str
    provider: str
    provider_name: str
    client_id: str
    authorization_url: str
    token_url: str
    scopes: _containers.RepeatedScalarFieldContainer[str]
    redirect_uris: _containers.RepeatedScalarFieldContainer[str]
    metadata: _containers.ScalarMap[str, str]
    server_ids: _containers.RepeatedScalarFieldContainer[str]
    status: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., provider: _Optional[str] = ..., provider_name: _Optional[str] = ..., client_id: _Optional[str] = ..., authorization_url: _Optional[str] = ..., token_url: _Optional[str] = ..., scopes: _Optional[_Iterable[str]] = ..., redirect_uris: _Optional[_Iterable[str]] = ..., metadata: _Optional[_Mapping[str, str]] = ..., server_ids: _Optional[_Iterable[str]] = ..., status: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class CreateMcpOAuthClientRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "provider", "provider_name", "client_id", "client_secret", "authorization_url", "token_url", "scopes", "redirect_uris", "metadata", "server_ids", "status")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_NAME_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_SECRET_FIELD_NUMBER: _ClassVar[int]
    AUTHORIZATION_URL_FIELD_NUMBER: _ClassVar[int]
    TOKEN_URL_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URIS_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SERVER_IDS_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    provider: str
    provider_name: str
    client_id: str
    client_secret: str
    authorization_url: str
    token_url: str
    scopes: _containers.RepeatedScalarFieldContainer[str]
    redirect_uris: _containers.RepeatedScalarFieldContainer[str]
    metadata: _containers.ScalarMap[str, str]
    server_ids: _containers.RepeatedScalarFieldContainer[str]
    status: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., provider: _Optional[str] = ..., provider_name: _Optional[str] = ..., client_id: _Optional[str] = ..., client_secret: _Optional[str] = ..., authorization_url: _Optional[str] = ..., token_url: _Optional[str] = ..., scopes: _Optional[_Iterable[str]] = ..., redirect_uris: _Optional[_Iterable[str]] = ..., metadata: _Optional[_Mapping[str, str]] = ..., server_ids: _Optional[_Iterable[str]] = ..., status: _Optional[str] = ...) -> None: ...

class GetMcpOAuthClientRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class ListMcpOAuthClientsRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "page")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    page: _types_pb2.PageRequest
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., page: _Optional[_Union[_types_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class ListMcpOAuthClientsResponse(_message.Message):
    __slots__ = ("clients", "page")
    CLIENTS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    clients: _containers.RepeatedCompositeFieldContainer[McpOAuthClient]
    page: _types_pb2.PageResponse
    def __init__(self, clients: _Optional[_Iterable[_Union[McpOAuthClient, _Mapping]]] = ..., page: _Optional[_Union[_types_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class UpdateMcpOAuthClientRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "id", "provider_name", "client_id", "client_secret", "authorization_url", "token_url", "status", "scopes", "redirect_uris", "metadata", "server_ids", "replace_scopes", "replace_redirect_uris", "replace_metadata", "replace_server_ids")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_NAME_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_SECRET_FIELD_NUMBER: _ClassVar[int]
    AUTHORIZATION_URL_FIELD_NUMBER: _ClassVar[int]
    TOKEN_URL_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URIS_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SERVER_IDS_FIELD_NUMBER: _ClassVar[int]
    REPLACE_SCOPES_FIELD_NUMBER: _ClassVar[int]
    REPLACE_REDIRECT_URIS_FIELD_NUMBER: _ClassVar[int]
    REPLACE_METADATA_FIELD_NUMBER: _ClassVar[int]
    REPLACE_SERVER_IDS_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    id: str
    provider_name: str
    client_id: str
    client_secret: str
    authorization_url: str
    token_url: str
    status: str
    scopes: _containers.RepeatedScalarFieldContainer[str]
    redirect_uris: _containers.RepeatedScalarFieldContainer[str]
    metadata: _containers.ScalarMap[str, str]
    server_ids: _containers.RepeatedScalarFieldContainer[str]
    replace_scopes: bool
    replace_redirect_uris: bool
    replace_metadata: bool
    replace_server_ids: bool
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., id: _Optional[str] = ..., provider_name: _Optional[str] = ..., client_id: _Optional[str] = ..., client_secret: _Optional[str] = ..., authorization_url: _Optional[str] = ..., token_url: _Optional[str] = ..., status: _Optional[str] = ..., scopes: _Optional[_Iterable[str]] = ..., redirect_uris: _Optional[_Iterable[str]] = ..., metadata: _Optional[_Mapping[str, str]] = ..., server_ids: _Optional[_Iterable[str]] = ..., replace_scopes: _Optional[bool] = ..., replace_redirect_uris: _Optional[bool] = ..., replace_metadata: _Optional[bool] = ..., replace_server_ids: _Optional[bool] = ...) -> None: ...

class DeleteMcpOAuthClientRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...



"""Typed errors for the agentrouter Python SDK.

Mirrors the canonical Connect error codes. The :class:`AgentrouterError` carries
the canonical ``code`` (lowercased gRPC status name) so callers can branch
without importing the underlying transport's error type.
"""

from __future__ import annotations

# Canonical lowercase code names -- what Connect-JSON puts in the
# ``"code"`` field of an error envelope.
CANCELLED = "canceled"
UNKNOWN = "unknown"
INVALID_ARGUMENT = "invalid_argument"
DEADLINE_EXCEEDED = "deadline_exceeded"
NOT_FOUND = "not_found"
ALREADY_EXISTS = "already_exists"
PERMISSION_DENIED = "permission_denied"
RESOURCE_EXHAUSTED = "resource_exhausted"
FAILED_PRECONDITION = "failed_precondition"
ABORTED = "aborted"
OUT_OF_RANGE = "out_of_range"
UNIMPLEMENTED = "unimplemented"
INTERNAL = "internal"
UNAVAILABLE = "unavailable"
DATA_LOSS = "data_loss"
UNAUTHENTICATED = "unauthenticated"

# Codes worth retrying transparently.
RETRYABLE = frozenset({UNAVAILABLE, DEADLINE_EXCEEDED, ABORTED})

# Mapping from HTTP status -> canonical code, used when the server does
# not return a Connect-JSON error envelope.
_HTTP_TO_CODE = {
    400: INVALID_ARGUMENT,
    401: UNAUTHENTICATED,
    403: PERMISSION_DENIED,
    404: NOT_FOUND,
    408: DEADLINE_EXCEEDED,
    409: ABORTED,
    412: FAILED_PRECONDITION,
    413: RESOURCE_EXHAUSTED,
    429: RESOURCE_EXHAUSTED,
    499: CANCELLED,
    500: INTERNAL,
    501: UNIMPLEMENTED,
    503: UNAVAILABLE,
    504: DEADLINE_EXCEEDED,
}


class AgentrouterError(Exception):
    """Raised when an RPC returns a non-OK status.

    Attributes:
        code:    canonical code (e.g. ``"not_found"``, ``"aborted"``).
        message: human-readable server detail.
        reason:  agentrouter-canonical machine-readable reason from the
                 ``reason`` field of the ``google.rpc.ErrorInfo`` detail the
                 platform attaches to every error (e.g. ``"MODEL_NOT_FOUND"``,
                 ``"CROSS_TENANT_DENIED"``). Mirrors the ``reason`` member of
                 the RFC 7807 Problem envelope. Empty string when absent.
        status:  raw HTTP status from the underlying response (when available).
    """

    def __init__(
        self,
        code: str,
        message: str = "",
        *,
        reason: str = "",
        status: int | None = None,
    ):
        super().__init__(message or code)
        self.code = code
        self.message = message
        self.reason = reason
        self.status = status

    def __str__(self) -> str:
        return f"{self.code}: {self.message}" if self.message else self.code

    def is_auth_required(self) -> bool:
        return self.code == UNAUTHENTICATED

    def is_not_found(self) -> bool:
        return self.code == NOT_FOUND

    def is_conflict(self) -> bool:
        return self.code in (ABORTED, ALREADY_EXISTS)

    def is_retryable(self) -> bool:
        return self.code in RETRYABLE


# Backwards-compatibility helpers for callers used to IA's exception type.
FailedPreconditionError = AgentrouterError

# Fully-qualified proto name of google.rpc.ErrorInfo, the detail type the
# platform attaches to every error. On the Connect-JSON wire it appears as a
# ``details[]`` entry: ``{"type": "google.rpc.ErrorInfo", "value": "<base64
# protobuf>", "debug": {"reason": "...", ...}}``.
_ERROR_INFO_TYPE = "google.rpc.ErrorInfo"


def _read_proto_field1_string(data: bytes) -> str:
    """Decode field 1 (a length-delimited string) from a protobuf message.

    A minimal reader for ``google.rpc.ErrorInfo``, whose ``reason`` is field 1
    (``string``). Other fields are skipped; malformed input yields "". This
    avoids a hard dependency on googleapis-common-protos for the one field the
    SDK surfaces.
    """
    pos, n = 0, len(data)
    while pos < n:
        # tag = (field_number << 3) | wire_type, as a varint.
        tag = 0
        shift = 0
        while pos < n:
            b = data[pos]
            pos += 1
            tag |= (b & 0x7F) << shift
            if not (b & 0x80):
                break
            shift += 7
        else:
            return ""
        field_no, wire_type = tag >> 3, tag & 0x07
        if field_no == 1 and wire_type == 2:  # length-delimited
            length = 0
            shift = 0
            while pos < n:
                b = data[pos]
                pos += 1
                length |= (b & 0x7F) << shift
                if not (b & 0x80):
                    break
                shift += 7
            else:
                return ""
            return data[pos : pos + length].decode("utf-8", errors="replace")
        # Skip any other field by its wire type.
        if wire_type == 0:  # varint
            while pos < n and (data[pos] & 0x80):
                pos += 1
            pos += 1
        elif wire_type == 2:  # length-delimited
            length = 0
            shift = 0
            while pos < n:
                b = data[pos]
                pos += 1
                length |= (b & 0x7F) << shift
                if not (b & 0x80):
                    break
                shift += 7
            pos += length
        elif wire_type == 5:  # 32-bit
            pos += 4
        elif wire_type == 1:  # 64-bit
            pos += 8
        else:
            return ""  # groups / unknown -- give up rather than misparse
    return ""


def _reason_from_envelope(envelope: dict) -> str:
    """Extract the google.rpc.ErrorInfo ``reason`` from a Connect-JSON error.

    Prefers the JSON ``debug`` representation connect-go emits for the detail;
    falls back to decoding the base64 ``value`` (binary ErrorInfo) so the
    reason is still recovered if ``debug`` is omitted. Returns "" when no
    ErrorInfo detail is present or it cannot be decoded.
    """
    import base64

    details = envelope.get("details")
    if not isinstance(details, list):
        return ""
    for detail in details:
        if not isinstance(detail, dict) or detail.get("type") != _ERROR_INFO_TYPE:
            continue
        debug = detail.get("debug")
        if isinstance(debug, dict):
            reason = debug.get("reason")
            if isinstance(reason, str) and reason:
                return reason
        value = detail.get("value")
        if isinstance(value, str) and value:
            try:
                raw = base64.b64decode(value)
            except (ValueError, TypeError):
                continue
            reason = _read_proto_field1_string(raw)
            if reason:
                return reason
    return ""


def from_http_response(status: int, body: bytes) -> AgentrouterError:
    """Translate a non-OK HTTP response into a :class:`AgentrouterError`.

    Tries to parse a Connect-JSON error envelope first; falls back to the
    canonical-code mapping for the HTTP status. When the envelope carries a
    ``google.rpc.ErrorInfo`` detail its ``reason`` is surfaced on the error.
    """
    import json

    code = _HTTP_TO_CODE.get(status, UNKNOWN)
    message = ""
    reason = ""
    try:
        envelope = json.loads(body)
        if isinstance(envelope, dict):
            code = str(envelope.get("code", code)) or code
            message = str(envelope.get("message", ""))
            reason = _reason_from_envelope(envelope)
    except (ValueError, TypeError):
        message = body.decode("utf-8", errors="replace")[:200]
    return AgentrouterError(code, message, reason=reason, status=status)



import datetime

from buf.validate import validate_pb2 as _validate_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from tars.auth.v1 import auth_options_pb2 as _auth_options_pb2
from tars.docs.v1 import docs_pb2 as _docs_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RegisterServiceAccountRequest(_message.Message):
    __slots__ = ("customer_id", "workspace_id", "client_email", "private_key_id", "issuer", "audience", "jwks_uri", "scopes", "expires_at", "public_keys", "checksum", "checksum_algorithm")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_EMAIL_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_KEY_ID_FIELD_NUMBER: _ClassVar[int]
    ISSUER_FIELD_NUMBER: _ClassVar[int]
    AUDIENCE_FIELD_NUMBER: _ClassVar[int]
    JWKS_URI_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEYS_FIELD_NUMBER: _ClassVar[int]
    CHECKSUM_FIELD_NUMBER: _ClassVar[int]
    CHECKSUM_ALGORITHM_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    workspace_id: str
    client_email: str
    private_key_id: str
    issuer: str
    audience: str
    jwks_uri: str
    scopes: _containers.RepeatedScalarFieldContainer[str]
    expires_at: _timestamp_pb2.Timestamp
    public_keys: _containers.RepeatedCompositeFieldContainer[PublicKey]
    checksum: str
    checksum_algorithm: str
    def __init__(self, customer_id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., client_email: _Optional[str] = ..., private_key_id: _Optional[str] = ..., issuer: _Optional[str] = ..., audience: _Optional[str] = ..., jwks_uri: _Optional[str] = ..., scopes: _Optional[_Iterable[str]] = ..., expires_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., public_keys: _Optional[_Iterable[_Union[PublicKey, _Mapping]]] = ..., checksum: _Optional[str] = ..., checksum_algorithm: _Optional[str] = ...) -> None: ...

class RegisterServiceAccountResponse(_message.Message):
    __slots__ = ("id", "created_at", "message")
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    id: str
    created_at: _timestamp_pb2.Timestamp
    message: str
    def __init__(self, id: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., message: _Optional[str] = ...) -> None: ...

class RevokeServiceAccountRequest(_message.Message):
    __slots__ = ("id", "reason")
    ID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    id: str
    reason: str
    def __init__(self, id: _Optional[str] = ..., reason: _Optional[str] = ...) -> None: ...

class RevokeServiceAccountResponse(_message.Message):
    __slots__ = ("id", "revoked_at", "message")
    ID_FIELD_NUMBER: _ClassVar[int]
    REVOKED_AT_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    id: str
    revoked_at: _timestamp_pb2.Timestamp
    message: str
    def __init__(self, id: _Optional[str] = ..., revoked_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., message: _Optional[str] = ...) -> None: ...

class GetServiceAccountRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetServiceAccountResponse(_message.Message):
    __slots__ = ("service_account",)
    SERVICE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    service_account: ServiceAccountInfo
    def __init__(self, service_account: _Optional[_Union[ServiceAccountInfo, _Mapping]] = ...) -> None: ...

class LookupServiceAccountRequest(_message.Message):
    __slots__ = ("customer_id", "workspace_id", "private_key_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_KEY_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    workspace_id: str
    private_key_id: str
    def __init__(self, customer_id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., private_key_id: _Optional[str] = ...) -> None: ...

class LookupServiceAccountResponse(_message.Message):
    __slots__ = ("service_account",)
    SERVICE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    service_account: ServiceAccountInfo
    def __init__(self, service_account: _Optional[_Union[ServiceAccountInfo, _Mapping]] = ...) -> None: ...

class ListServiceAccountsRequest(_message.Message):
    __slots__ = ("customer_id", "workspace_id", "include_revoked", "page_size", "page_token")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_REVOKED_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    workspace_id: str
    include_revoked: bool
    page_size: int
    page_token: str
    def __init__(self, customer_id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., include_revoked: _Optional[bool] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class ListServiceAccountsResponse(_message.Message):
    __slots__ = ("service_accounts", "next_page_token", "total_count")
    SERVICE_ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_COUNT_FIELD_NUMBER: _ClassVar[int]
    service_accounts: _containers.RepeatedCompositeFieldContainer[ServiceAccountInfo]
    next_page_token: str
    total_count: int
    def __init__(self, service_accounts: _Optional[_Iterable[_Union[ServiceAccountInfo, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_count: _Optional[int] = ...) -> None: ...

class GetServiceAccountPublicKeysRequest(_message.Message):
    __slots__ = ("service_account_id",)
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    service_account_id: str
    def __init__(self, service_account_id: _Optional[str] = ...) -> None: ...

class GetServiceAccountPublicKeysResponse(_message.Message):
    __slots__ = ("public_keys",)
    PUBLIC_KEYS_FIELD_NUMBER: _ClassVar[int]
    public_keys: _containers.RepeatedCompositeFieldContainer[PublicKey]
    def __init__(self, public_keys: _Optional[_Iterable[_Union[PublicKey, _Mapping]]] = ...) -> None: ...

class ServiceAccountInfo(_message.Message):
    __slots__ = ("id", "customer_id", "workspace_id", "client_email", "private_key_id", "issuer", "audience", "jwks_uri", "scopes", "created_at", "expires_at", "revoked_at", "revoked_reason", "checksum", "checksum_algorithm")
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_EMAIL_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_KEY_ID_FIELD_NUMBER: _ClassVar[int]
    ISSUER_FIELD_NUMBER: _ClassVar[int]
    AUDIENCE_FIELD_NUMBER: _ClassVar[int]
    JWKS_URI_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    REVOKED_AT_FIELD_NUMBER: _ClassVar[int]
    REVOKED_REASON_FIELD_NUMBER: _ClassVar[int]
    CHECKSUM_FIELD_NUMBER: _ClassVar[int]
    CHECKSUM_ALGORITHM_FIELD_NUMBER: _ClassVar[int]
    id: str
    customer_id: str
    workspace_id: str
    client_email: str
    private_key_id: str
    issuer: str
    audience: str
    jwks_uri: str
    scopes: _containers.RepeatedScalarFieldContainer[str]
    created_at: _timestamp_pb2.Timestamp
    expires_at: _timestamp_pb2.Timestamp
    revoked_at: _timestamp_pb2.Timestamp
    revoked_reason: str
    checksum: str
    checksum_algorithm: str
    def __init__(self, id: _Optional[str] = ..., customer_id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., client_email: _Optional[str] = ..., private_key_id: _Optional[str] = ..., issuer: _Optional[str] = ..., audience: _Optional[str] = ..., jwks_uri: _Optional[str] = ..., scopes: _Optional[_Iterable[str]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., expires_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., revoked_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., revoked_reason: _Optional[str] = ..., checksum: _Optional[str] = ..., checksum_algorithm: _Optional[str] = ...) -> None: ...

class PublicKey(_message.Message):
    __slots__ = ("kid", "alg", "use", "key_pem", "created_at")
    KID_FIELD_NUMBER: _ClassVar[int]
    ALG_FIELD_NUMBER: _ClassVar[int]
    USE_FIELD_NUMBER: _ClassVar[int]
    KEY_PEM_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    kid: str
    alg: str
    use: str
    key_pem: str
    created_at: _timestamp_pb2.Timestamp
    def __init__(self, kid: _Optional[str] = ..., alg: _Optional[str] = ..., use: _Optional[str] = ..., key_pem: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class CreateRegistryCredentialRequest(_message.Message):
    __slots__ = ("customer_id", "workspace_id", "description", "expires_at", "scopes")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    workspace_id: str
    description: str
    expires_at: _timestamp_pb2.Timestamp
    scopes: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, customer_id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., description: _Optional[str] = ..., expires_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., scopes: _Optional[_Iterable[str]] = ...) -> None: ...

class CreateRegistryCredentialResponse(_message.Message):
    __slots__ = ("id", "username", "password", "created_at", "message")
    ID_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    id: str
    username: str
    password: str
    created_at: _timestamp_pb2.Timestamp
    message: str
    def __init__(self, id: _Optional[str] = ..., username: _Optional[str] = ..., password: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., message: _Optional[str] = ...) -> None: ...

class ListRegistryCredentialsRequest(_message.Message):
    __slots__ = ("customer_id", "workspace_id", "include_revoked", "page_size", "page_token")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_REVOKED_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    workspace_id: str
    include_revoked: bool
    page_size: int
    page_token: str
    def __init__(self, customer_id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., include_revoked: _Optional[bool] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class ListRegistryCredentialsResponse(_message.Message):
    __slots__ = ("credentials", "next_page_token", "total_count")
    CREDENTIALS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_COUNT_FIELD_NUMBER: _ClassVar[int]
    credentials: _containers.RepeatedCompositeFieldContainer[RegistryCredentialInfo]
    next_page_token: str
    total_count: int
    def __init__(self, credentials: _Optional[_Iterable[_Union[RegistryCredentialInfo, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_count: _Optional[int] = ...) -> None: ...

class RevokeRegistryCredentialRequest(_message.Message):
    __slots__ = ("id", "reason")
    ID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    id: str
    reason: str
    def __init__(self, id: _Optional[str] = ..., reason: _Optional[str] = ...) -> None: ...

class RevokeRegistryCredentialResponse(_message.Message):
    __slots__ = ("id", "revoked_at", "message")
    ID_FIELD_NUMBER: _ClassVar[int]
    REVOKED_AT_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    id: str
    revoked_at: _timestamp_pb2.Timestamp
    message: str
    def __init__(self, id: _Optional[str] = ..., revoked_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., message: _Optional[str] = ...) -> None: ...

class RegistryCredentialInfo(_message.Message):
    __slots__ = ("id", "customer_id", "workspace_id", "username", "description", "scopes", "created_at", "created_by", "expires_at", "last_used_at", "revoked_at", "revoked_reason", "revoked_by")
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    LAST_USED_AT_FIELD_NUMBER: _ClassVar[int]
    REVOKED_AT_FIELD_NUMBER: _ClassVar[int]
    REVOKED_REASON_FIELD_NUMBER: _ClassVar[int]
    REVOKED_BY_FIELD_NUMBER: _ClassVar[int]
    id: str
    customer_id: str
    workspace_id: str
    username: str
    description: str
    scopes: _containers.RepeatedScalarFieldContainer[str]
    created_at: _timestamp_pb2.Timestamp
    created_by: str
    expires_at: _timestamp_pb2.Timestamp
    last_used_at: _timestamp_pb2.Timestamp
    revoked_at: _timestamp_pb2.Timestamp
    revoked_reason: str
    revoked_by: str
    def __init__(self, id: _Optional[str] = ..., customer_id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., username: _Optional[str] = ..., description: _Optional[str] = ..., scopes: _Optional[_Iterable[str]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., created_by: _Optional[str] = ..., expires_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., last_used_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., revoked_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., revoked_reason: _Optional[str] = ..., revoked_by: _Optional[str] = ...) -> None: ...

class PingRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class PingResponse(_message.Message):
    __slots__ = ("message", "timestamp")
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    message: str
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, message: _Optional[str] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



import datetime

from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from tars.auth.v1 import auth_options_pb2 as _auth_options_pb2
from tars.cli.v1 import cli_pb2 as _cli_pb2
from tars.docs.v1 import docs_pb2 as _docs_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListCustomerRequestLogsRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "api_key_id", "model_name", "status", "status_code", "start_time", "end_time", "min_duration_ms", "max_duration_ms", "page_size", "page_token", "order_by", "order_direction")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    API_KEY_ID_FIELD_NUMBER: _ClassVar[int]
    MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    MIN_DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    MAX_DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    ORDER_DIRECTION_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    api_key_id: str
    model_name: str
    status: str
    status_code: int
    start_time: _timestamp_pb2.Timestamp
    end_time: _timestamp_pb2.Timestamp
    min_duration_ms: int
    max_duration_ms: int
    page_size: int
    page_token: str
    order_by: str
    order_direction: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., api_key_id: _Optional[str] = ..., model_name: _Optional[str] = ..., status: _Optional[str] = ..., status_code: _Optional[int] = ..., start_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., end_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., min_duration_ms: _Optional[int] = ..., max_duration_ms: _Optional[int] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., order_by: _Optional[str] = ..., order_direction: _Optional[str] = ...) -> None: ...

class ListCustomerRequestLogsResponse(_message.Message):
    __slots__ = ("logs", "next_page_token", "total_count")
    LOGS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_COUNT_FIELD_NUMBER: _ClassVar[int]
    logs: _containers.RepeatedCompositeFieldContainer[RequestLog]
    next_page_token: str
    total_count: int
    def __init__(self, logs: _Optional[_Iterable[_Union[RequestLog, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_count: _Optional[int] = ...) -> None: ...

class GetCustomerRequestLogRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "request_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    request_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., request_id: _Optional[str] = ...) -> None: ...

class GetCustomerRequestLogStatsRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "model_name", "start_time", "end_time", "group_by", "metric")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    METRIC_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    model_name: str
    start_time: _timestamp_pb2.Timestamp
    end_time: _timestamp_pb2.Timestamp
    group_by: str
    metric: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., model_name: _Optional[str] = ..., start_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., end_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., group_by: _Optional[str] = ..., metric: _Optional[str] = ...) -> None: ...

class QueryRequestLogsRequest(_message.Message):
    __slots__ = ("user_id", "api_key_id", "model_name", "status", "status_code", "start_time", "end_time", "min_duration_ms", "max_duration_ms", "page_size", "page_token", "order_by", "order_direction")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    API_KEY_ID_FIELD_NUMBER: _ClassVar[int]
    MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    MIN_DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    MAX_DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    ORDER_DIRECTION_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    api_key_id: str
    model_name: str
    status: str
    status_code: int
    start_time: _timestamp_pb2.Timestamp
    end_time: _timestamp_pb2.Timestamp
    min_duration_ms: int
    max_duration_ms: int
    page_size: int
    page_token: str
    order_by: str
    order_direction: str
    def __init__(self, user_id: _Optional[str] = ..., api_key_id: _Optional[str] = ..., model_name: _Optional[str] = ..., status: _Optional[str] = ..., status_code: _Optional[int] = ..., start_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., end_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., min_duration_ms: _Optional[int] = ..., max_duration_ms: _Optional[int] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., order_by: _Optional[str] = ..., order_direction: _Optional[str] = ...) -> None: ...

class QueryRequestLogsResponse(_message.Message):
    __slots__ = ("logs", "next_page_token", "total_count")
    LOGS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_COUNT_FIELD_NUMBER: _ClassVar[int]
    logs: _containers.RepeatedCompositeFieldContainer[RequestLog]
    next_page_token: str
    total_count: int
    def __init__(self, logs: _Optional[_Iterable[_Union[RequestLog, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_count: _Optional[int] = ...) -> None: ...

class GetRequestLogRequest(_message.Message):
    __slots__ = ("request_id",)
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    request_id: str
    def __init__(self, request_id: _Optional[str] = ...) -> None: ...

class RequestLog(_message.Message):
    __slots__ = ("id", "timestamp", "user_id", "api_key_id", "api_key_prefix", "api_key_hash", "api_key_address", "api_key_name", "model_name", "input_tokens", "output_tokens", "input_tokens_cost_microdollar", "input_tokens_cost", "input_tokens_cost_before_fee", "output_tokens_cost_microdollar", "output_tokens_cost", "output_tokens_cost_before_fee", "status", "status_code", "request_headers", "request_body", "response_headers", "response_body", "response_body_raw", "llm_parameters", "upstream_duration_ms", "duration_ms", "request_id", "created_at", "storage_location", "storage_row_index", "storage_batch_id", "use_object_storage", "cached_input_tokens", "cached_input_tokens_cost", "cached_input_tokens_cost_before_fee", "cache_creation_input_tokens", "cache_creation_input_tokens_cost", "cache_creation_input_tokens_cost_before_fee")
    ID_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    API_KEY_ID_FIELD_NUMBER: _ClassVar[int]
    API_KEY_PREFIX_FIELD_NUMBER: _ClassVar[int]
    API_KEY_HASH_FIELD_NUMBER: _ClassVar[int]
    API_KEY_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    API_KEY_NAME_FIELD_NUMBER: _ClassVar[int]
    MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    INPUT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    INPUT_TOKENS_COST_MICRODOLLAR_FIELD_NUMBER: _ClassVar[int]
    INPUT_TOKENS_COST_FIELD_NUMBER: _ClassVar[int]
    INPUT_TOKENS_COST_BEFORE_FEE_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_TOKENS_COST_MICRODOLLAR_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_TOKENS_COST_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_TOKENS_COST_BEFORE_FEE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    REQUEST_HEADERS_FIELD_NUMBER: _ClassVar[int]
    REQUEST_BODY_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_HEADERS_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_BODY_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_BODY_RAW_FIELD_NUMBER: _ClassVar[int]
    LLM_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    UPSTREAM_DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    STORAGE_LOCATION_FIELD_NUMBER: _ClassVar[int]
    STORAGE_ROW_INDEX_FIELD_NUMBER: _ClassVar[int]
    STORAGE_BATCH_ID_FIELD_NUMBER: _ClassVar[int]
    USE_OBJECT_STORAGE_FIELD_NUMBER: _ClassVar[int]
    CACHED_INPUT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    CACHED_INPUT_TOKENS_COST_FIELD_NUMBER: _ClassVar[int]
    CACHED_INPUT_TOKENS_COST_BEFORE_FEE_FIELD_NUMBER: _ClassVar[int]
    CACHE_CREATION_INPUT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    CACHE_CREATION_INPUT_TOKENS_COST_FIELD_NUMBER: _ClassVar[int]
    CACHE_CREATION_INPUT_TOKENS_COST_BEFORE_FEE_FIELD_NUMBER: _ClassVar[int]
    id: str
    timestamp: _timestamp_pb2.Timestamp
    user_id: str
    api_key_id: str
    api_key_prefix: str
    api_key_hash: str
    api_key_address: str
    api_key_name: str
    model_name: str
    input_tokens: int
    output_tokens: int
    input_tokens_cost_microdollar: int
    input_tokens_cost: str
    input_tokens_cost_before_fee: str
    output_tokens_cost_microdollar: int
    output_tokens_cost: str
    output_tokens_cost_before_fee: str
    status: str
    status_code: int
    request_headers: _struct_pb2.Struct
    request_body: _struct_pb2.Struct
    response_headers: _struct_pb2.Struct
    response_body: str
    response_body_raw: bytes
    llm_parameters: _struct_pb2.Struct
    upstream_duration_ms: int
    duration_ms: int
    request_id: str
    created_at: _timestamp_pb2.Timestamp
    storage_location: str
    storage_row_index: int
    storage_batch_id: str
    use_object_storage: bool
    cached_input_tokens: int
    cached_input_tokens_cost: str
    cached_input_tokens_cost_before_fee: str
    cache_creation_input_tokens: int
    cache_creation_input_tokens_cost: str
    cache_creation_input_tokens_cost_before_fee: str
    def __init__(self, id: _Optional[str] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., user_id: _Optional[str] = ..., api_key_id: _Optional[str] = ..., api_key_prefix: _Optional[str] = ..., api_key_hash: _Optional[str] = ..., api_key_address: _Optional[str] = ..., api_key_name: _Optional[str] = ..., model_name: _Optional[str] = ..., input_tokens: _Optional[int] = ..., output_tokens: _Optional[int] = ..., input_tokens_cost_microdollar: _Optional[int] = ..., input_tokens_cost: _Optional[str] = ..., input_tokens_cost_before_fee: _Optional[str] = ..., output_tokens_cost_microdollar: _Optional[int] = ..., output_tokens_cost: _Optional[str] = ..., output_tokens_cost_before_fee: _Optional[str] = ..., status: _Optional[str] = ..., status_code: _Optional[int] = ..., request_headers: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., request_body: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., response_headers: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., response_body: _Optional[str] = ..., response_body_raw: _Optional[bytes] = ..., llm_parameters: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., upstream_duration_ms: _Optional[int] = ..., duration_ms: _Optional[int] = ..., request_id: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., storage_location: _Optional[str] = ..., storage_row_index: _Optional[int] = ..., storage_batch_id: _Optional[str] = ..., use_object_storage: _Optional[bool] = ..., cached_input_tokens: _Optional[int] = ..., cached_input_tokens_cost: _Optional[str] = ..., cached_input_tokens_cost_before_fee: _Optional[str] = ..., cache_creation_input_tokens: _Optional[int] = ..., cache_creation_input_tokens_cost: _Optional[str] = ..., cache_creation_input_tokens_cost_before_fee: _Optional[str] = ...) -> None: ...

class GetRequestLogStatsRequest(_message.Message):
    __slots__ = ("user_id", "model_name", "start_time", "end_time", "group_by", "metric")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    METRIC_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    model_name: str
    start_time: _timestamp_pb2.Timestamp
    end_time: _timestamp_pb2.Timestamp
    group_by: str
    metric: str
    def __init__(self, user_id: _Optional[str] = ..., model_name: _Optional[str] = ..., start_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., end_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., group_by: _Optional[str] = ..., metric: _Optional[str] = ...) -> None: ...

class RequestLogStatsResponse(_message.Message):
    __slots__ = ("stats", "total_count", "total_input_tokens", "total_output_tokens", "total_cost", "avg_duration_ms", "error_count")
    STATS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_COUNT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_INPUT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_OUTPUT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_COST_FIELD_NUMBER: _ClassVar[int]
    AVG_DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    ERROR_COUNT_FIELD_NUMBER: _ClassVar[int]
    stats: _containers.RepeatedCompositeFieldContainer[StatEntry]
    total_count: int
    total_input_tokens: int
    total_output_tokens: int
    total_cost: str
    avg_duration_ms: float
    error_count: int
    def __init__(self, stats: _Optional[_Iterable[_Union[StatEntry, _Mapping]]] = ..., total_count: _Optional[int] = ..., total_input_tokens: _Optional[int] = ..., total_output_tokens: _Optional[int] = ..., total_cost: _Optional[str] = ..., avg_duration_ms: _Optional[float] = ..., error_count: _Optional[int] = ...) -> None: ...

class StatEntry(_message.Message):
    __slots__ = ("key", "count", "error_count", "input_tokens", "output_tokens", "total_tokens", "cost", "cost_microdollar", "avg_duration_ms", "min_duration_ms", "max_duration_ms", "p50_duration_ms", "p95_duration_ms", "p99_duration_ms")
    KEY_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    ERROR_COUNT_FIELD_NUMBER: _ClassVar[int]
    INPUT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_TOKENS_FIELD_NUMBER: _ClassVar[int]
    COST_FIELD_NUMBER: _ClassVar[int]
    COST_MICRODOLLAR_FIELD_NUMBER: _ClassVar[int]
    AVG_DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    MIN_DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    MAX_DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    P50_DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    P95_DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    P99_DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    key: str
    count: int
    error_count: int
    input_tokens: int
    output_tokens: int
    total_tokens: int
    cost: str
    cost_microdollar: int
    avg_duration_ms: int
    min_duration_ms: int
    max_duration_ms: int
    p50_duration_ms: int
    p95_duration_ms: int
    p99_duration_ms: int
    def __init__(self, key: _Optional[str] = ..., count: _Optional[int] = ..., error_count: _Optional[int] = ..., input_tokens: _Optional[int] = ..., output_tokens: _Optional[int] = ..., total_tokens: _Optional[int] = ..., cost: _Optional[str] = ..., cost_microdollar: _Optional[int] = ..., avg_duration_ms: _Optional[int] = ..., min_duration_ms: _Optional[int] = ..., max_duration_ms: _Optional[int] = ..., p50_duration_ms: _Optional[int] = ..., p95_duration_ms: _Optional[int] = ..., p99_duration_ms: _Optional[int] = ...) -> None: ...



import datetime

from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ProjectState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PROJECT_STATE_UNSPECIFIED: _ClassVar[ProjectState]
    PROJECT_STATE_ACTIVE: _ClassVar[ProjectState]
    PROJECT_STATE_ARCHIVED: _ClassVar[ProjectState]
PROJECT_STATE_UNSPECIFIED: ProjectState
PROJECT_STATE_ACTIVE: ProjectState
PROJECT_STATE_ARCHIVED: ProjectState

class Project(_message.Message):
    __slots__ = ("id", "customer_id", "project_id", "display_name", "description", "state", "labels", "created_at", "updated_at", "archived_at")
    class LabelsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    ARCHIVED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    customer_id: str
    project_id: str
    display_name: str
    description: str
    state: ProjectState
    labels: _containers.ScalarMap[str, str]
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    archived_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., display_name: _Optional[str] = ..., description: _Optional[str] = ..., state: _Optional[_Union[ProjectState, str]] = ..., labels: _Optional[_Mapping[str, str]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., archived_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ProjectMember(_message.Message):
    __slots__ = ("id", "customer_id", "project_id", "identity_id", "role", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_ID_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    customer_id: str
    project_id: str
    identity_id: str
    role: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., identity_id: _Optional[str] = ..., role: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
